﻿using NeoTicker;
using System;
using System.Windows.Forms;
using System.Security;
using System.Diagnostics;

namespace NeoCTV
{
    [SuppressUnmanagedCodeSecurity]
    public class EntryPointClass : IDLIndicator
    {
        bool settingsOK;
        int lookBackSeconds;
        int ticksBack;

        public double IDLCallEx(NTIndicatorObjects N)
        {
            if (N.ItSelf().FirstCall)
            {
                settingsOK = CheckIfSettingsOK(N, ref lookBackSeconds);
            }

            if (settingsOK)
            {
                ticksBack = 0;
                while (N.Data1().get_Valid(ticksBack) && SecondsDiff(ticksBack, N.Data1()) <= lookBackSeconds - 1)
                {
                    ticksBack++;
                }

                if (N.Data1().get_Valid(ticksBack))
                {
                    N.ItSelf().set_Plot(1, ticksBack);
                }
                else
                {
                    N.ItSelf().Success = false;
                }
            }
            else
            {
                N.ItSelf().Success = false;
            }

            return 0;
        }

        private static int SecondsDiff(int BarsAgo, DataObj Data)
        {
            return 86400 * ((int)Data.get_Date(0) - (int)Data.get_Date(BarsAgo))
                    + 3600 * (Data.get_Hour(0) - Data.get_Hour(BarsAgo))
                    + 60 * (Data.get_Minute(0) - Data.get_Minute(BarsAgo))
                    + (Data.get_Second(0) - Data.get_Second(BarsAgo));
        }

        private static bool CheckIfSettingsOK(NTIndicatorObjects N, ref int lookBackSeconds)
        {
            lookBackSeconds = N.Params().get_Items("Seconds Back").Int;
            string lookBackErrorMsg = "";
            string timeFrameErrorMsg = "";
            string commonErrorMessage = "CTV indicator has been disabled.\n\n"
                            + "Please consult the CTV thread at kreslik.com for further information on CTV usage.\n\n"
                            + "Do you wish to go to the kreslik.com thread on CTV?";
            bool error = false;

            if (lookBackSeconds < 1)
            {
                lookBackErrorMsg = "Lookback error:\n"
                                    + "The minimum lookback period for CTV indicator is 1 second.\n"
                                    + "Your lookback setting is " + lookBackSeconds.ToString() + " seconds.\n\n";
                error = true;
            }

            if (!(N.ItSelf().TimeFrameType == DataTimeFrameType.ppTick && N.ItSelf().TimeFramePeriod == 1))
            {
                string timeFrame = N.ItSelf().TimeFramePeriod.ToString() + " " + (N.ItSelf().TimeFrameType.ToString()).Substring(2);
                timeFrameErrorMsg = "Timeframe error:\n"
                                    + "CTV indicator is designed to be applied to 1 Tick charts only.\n"
                                    + "This chart's timeframe is " + timeFrame + ".\n\n";
                error = true;
            }

            if (error)
            {
                string message = lookBackErrorMsg + timeFrameErrorMsg + commonErrorMessage;
                string caption = "CTV error";
                if (MessageBox.Show(message, caption, MessageBoxButtons.YesNo, MessageBoxIcon.Information) == DialogResult.Yes)
                {
                    try
                    {
                        Process.Start(@"C:\Program Files\Internet Explorer\IEXPLORE.EXE", @"http://kreslik.com/forums/viewtopic.php?t=340");
                    }
                    catch (Exception e)
                    {
                        MessageBox.Show(e.Message, "Error launching Internet Explorer", MessageBoxButtons.OK, MessageBoxIcon.Information);
                    }
                }

                return false;
            }
            else
            {
                return true;
            }

        }
    }
}
